import json
from requests import get

url = 'https://lgdirectory.dlgrma.qld.gov.au/php/councilList.php'

def get_councils():
    _councils = []
    council_data = json.loads(get(url).text)
    for council in council_data:
        _councils.append(council['councilname'])
    return(_councils)

councils = get_councils()


from requests import get
from bs4 import BeautifulSoup

url = 'https://walga.asn.au/About-Local-Government/Online-Local-Government-Directory?letter=&page='

def get_councils():
    _council_list = []
    for i in range(1,15):
        soup = BeautifulSoup(get(url + str(i)).text, 'lxml').find('div', {'class': 'col-md-12 main-content'}).find_all('div', {'class': 'data-council'})
        for council in soup:
            _council_list.append(council.find('a').text)
    return(_council_list)

councils = get_councils()


from requests import get
from bs4 import BeautifulSoup

url = 'https://knowyourcouncil.vic.gov.au/councils'

def get_councils():
    _council_names = []
    div = BeautifulSoup(get(url).text, 'lxml')
    councils = div.find_all('li')
    for council in councils[9:]:
        _council_names.append(council.text)
    return _council_names

councils = get_councils()


from requests import get
from bs4 import BeautifulSoup

url = 'http://www.dpac.tas.gov.au/divisions/local_government/local_government_directory'

def get_councils():
    _councils = []
    council_names = BeautifulSoup(get(url).text, 'lxml').find('select', {'name': 'lgc'}).find_all('option')
    for council in council_names:
        _councils.append('%s Council' % (council.text))
    return(_councils)

councils = get_councils()


from bs4 import BeautifulSoup
from requests import get

url = 'https://www.lgant.asn.au/councils-2/'
headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:83.0) Gecko/20100101 Firefox/83.0'} # 2000 IQ security bypass

def get_councils():
    _councils = []
    council_names = BeautifulSoup(get(url, headers=headers).text, 'lxml').find_all('h5', {'class': 'et_pb_toggle_title'})
    for council in council_names[1:]:
        _councils.append(council.text.strip().title())
    return(_councils)

councils = get_councils()


from requests import get
from bs4 import BeautifulSoup

url = 'https://www.ecsa.sa.gov.au/council-links'

def get_councils():
    council_list = []
    _list = BeautifulSoup(get(url).text, 'lxml').find('div', {'class': 'content-text'}).find_all('li')
    for council in _list:
        council_list.append(council.text.replace('\u00a0', ' '))
    return(council_list)

councils = get_councils()